/*
 * nvr8260.h
 *
 *
 * This file is the configuration file for NVR MPC8250 based board.
 */

#ifndef __CONFIG_H
#define __CONFIG_H

/****************************************************************************
 *
 * u-boot Configurations
 *
 ****************************************************************************/

/* Architecture */
#define CONFIG_MPC8260          1       /* This is an MPC8260 CPU   */
#define CONFIG_NVR8260          1       /* NVR Board Rev A */

/* Procedure */
#define CONFIG_BOARD_EARLY_INIT_F       1     /* Call board_early_init_f  */

/* Auto-boot */
#define CONFIG_BOOTDELAY        -1      /* Disable auto-boot */

/* Decrementer */
#define CFG_HZ                  1000

/* UART */
#define CONFIG_BAUDRATE         115200
#define CFG_BAUDRATE_TABLE      { 9600, 19200, 38400, 57600, 115200 }

/* Network */
#define CONFIG_ETHADDR          00:10:EC:00:30:8C
#define CONFIG_IPADDR           192.168.58.43
#define CONFIG_SERVERIP         192.168.58.41

/* Command prompt */
#define CFG_LONGHELP
#define CFG_PROMPT              "boot> "
#define CFG_HUSH_PARSER
#define CFG_PROMPT_HUSH_PS2     "> "

/* Supported commands */
#define CONFIG_COMMANDS         (CFG_CMD_ALL        & \
                                ~CFG_CMD_BMP        & \
                                ~CFG_CMD_BSP        & \
                                ~CFG_CMD_DATE       & \
                                ~CFG_CMD_DCR        & \
                                ~CFG_CMD_DHCP       & \
                                ~CFG_CMD_DOC        & \
                                ~CFG_CMD_EEPROM     & \
                                ~CFG_CMD_FDC        & \
                                ~CFG_CMD_FDOS       & \
                                ~CFG_CMD_HWFLOW     & \
                                ~CFG_CMD_IDE        & \
                                ~CFG_CMD_JFFS2      & \
                                ~CFG_CMD_KGDB       & \
                                ~CFG_CMD_MII        & \
                                ~CFG_CMD_MMC        & \
                                ~CFG_CMD_NAND       & \
                                ~CFG_CMD_PCI        & \
                                ~CFG_CMD_PCMCIA     & \
                                ~CFG_CMD_SCSI       & \
                                ~CFG_CMD_REISER     & \
                                ~CFG_CMD_SPI        & \
                                ~CFG_CMD_USB        & \
                                ~CFG_CMD_VFD        & \
                                ~CFG_CMD_DTT)

#include <cmd_confdefs.h>

/* Console buffer size */
#if (CONFIG_COMMANDS & CFG_CMD_KGDB)
#  define CFG_CBSIZE            1024
#else
#  define CFG_CBSIZE            256
#endif

/* Print buffer size */
#define CFG_PBSIZE              (CFG_CBSIZE + sizeof(CFG_PROMPT) + 16)

/* Command buffer */
#define CFG_MAXARGS             8
#define CFG_BARGSIZE            CFG_CBSIZE

/* Memory test */
#define CFG_MEMTEST_START       0x00000000
#define CFG_MEMTEST_END         0x10000000

/* Addresses */
#define CFG_LOAD_ADDR           0x00100000  /* default load address */
#define CFG_TFTP_LOADADDR       0x00100000  /* default load address for network file downloads */

/* Final memory configuration */
#define CFG_MONITOR_BASE        TEXT_BASE
#define CFG_MONITOR_LEN         (256 << 10) /* Reserve 256 kB for Monitor   */
#define CFG_MALLOC_LEN          (128 << 10) /* Reserve 128 kB for malloc()  */

/* Interface with Linux */
// #define CONFIG_CLOCKS_IN_MHZ    1           /* clocks passsed to Linux in MHz */
#define CFG_BOOTMAPSZ           (8 << 20)   /* Initial Memory map for Linux */

/*
 * Internal Definitions
 */

/* Boot flags */
#define BOOTFLAG_COLD           0x01        /* Normal Power-On: Boot from FLASH  */
#define BOOTFLAG_WARM           0x02        /* Software reboot                   */

/****************************************************************************
 * 
 * System Information
 *
 ****************************************************************************/

/*
 * Clock configuration
 *
 * CLKIN : 66MHz
 * MODCK[7-4] : 0b0111 (0x07)
 * MODCK[3-1] : 0b110 (0x06)
 * 
 * CPM frequency = 200MHz
 * Core frequency = 300MHz
 */

#define CONFIG_8260_CLKIN       (66 * 1000 * 1000)
#define CFG_SBC_MODCK_H         0x07

/*
 * Reset configuration
 *
 * Boot high : exception vector = 0xFFF00000
 */

#undef CFG_SBC_BOOT_LOW
#define CFG_RESET_ADDRESS       0xFFF00100

/*
 * Memory Map
 *
 * 0x00000000 - 0x0FFFFFFF : SDRAM (256MB)
 * 0x20000000 - 0x20003FFF : CXE-1000 Packet FIFO (16KB)
 * 0x21000000 - 0x21003FFF : CXE-1000 Configuration Registers (16KB)
 * 0x40000000 - 0x41FFFFFF : FLASH (32MB)
 * 0x50000000 - 0x50000FFF : CPLD (4KB)
 * 0xF0000000 - 0xF00FFFFF : IMMR Space (1MB)
 */

/* Flash memory */
#define CFG_FLASH0_BASE         0xFE000000
#define CFG_FLASH0_SIZE         32
#undef CFG_FLASH1_BASE
#undef CFG_FLASH1_SIZE

/* Switch core, sizes in bytes */
#define CFG_SWITCHCORE_REG_BASE         0x21000000
#define CFG_SWITCHCORE_REG_SIZE         0x1000
#define CFG_SWITCHCORE_PACKET_BASE      0x20000000
#define CFG_SWITCHCORE_PACKET_SIZE      0x1000

/* SDRAM */
#define CFG_SDRAM0_BASE         0x00000000
#define CFG_SDRAM0_SIZE         256

/* Local SDRAM : None */
#undef CFG_LSDRAM
#undef CFG_SDRAM1_BASE
#undef CFG_SDRAM1_SIZE

/* IMMR Space */
#define CFG_IMMR                0xF0000000
// #define CFG_DEFAULT_IMMR        0xF0010000

/* Memory Base */
#define CFG_FLASH_BASE          CFG_FLASH0_BASE
#define CFG_SDRAM_BASE          CFG_SDRAM0_BASE

/*
 * Serial Console
 *
 * SCC1 : Console
 */

#undef  CONFIG_CONS_NONE
#undef  CONFIG_CONS_ON_SMC
#define CONFIG_CONS_ON_SCC
#define CONFIG_CONS_INDEX       1

/*
 * Ethernet
 *
 * FCC1 : CXE-1000
 * FCC2 : Management ethernet
 * FCC3 : Redundancy ethernet (default)
 *
 * Clock routing
 *
 * PHY1_TX_CLK : CLK9
 * PHY1_RX_CLK : CLK10
 * PHY2_TX_CLK : CLK13
 * PHY2_RX_CLK : CLK14
 * PHY3_TX_CLK : CLK15
 * PHY3_RX_CLK : CLK16
 */

#undef  CONFIG_ETHER_NONE
#undef  CONFIG_ETHER_ON_SCC
#define CONFIG_ETHER_ON_FCC
#define CONFIG_ETHER_INDEX      3

#define CFG_CMXFCR_MASK         (CMXFCR_FC3 | CMXFCR_RF3CS_MSK | CMXFCR_TF3CS_MSK)
#define CFG_CMXFCR_VALUE        (CMXFCR_RF3CS_CLK16 | CMXFCR_TF3CS_CLK15)

/* CPM/FCR : The data is located on 60x bus (no Local SDRAM) */
#define CFG_CPMFCR_RAMTYPE      0

/* PSMR : full duplex */
#define CFG_FCC_PSMR            (FCC_PSMR_FDE | FCC_PSMR_LPB)

/*
 * I2C
 *
 * I2C_CLK : PD14
 * I2C_DATA : PD15
 *
 * I2C devices
 * 
 * ADM1026 SYS MAN : 0x2e
 * DS1374 WD/RTC : 0x68
 * PCA8581 EEPROM : 0x50
 */

#define CONFIG_HARD_I2C         1        /* I2C with hardware support    */
#undef CONFIG_SOFT_I2C         1       /* I2C bit-banged               */
#define CFG_I2C_SPEED           400000  /* I2C speed and slave address  */
#define CFG_I2C_SLAVE           0x7F    /* CPU's I2C node address       */

#ifdef CONFIG_SOFT_I2C
#define I2C_PORT                3       /* Port A=0, B=1, C=2, D=3      */
#define I2C_ACTIVE              (iop->pdir |=  0x00010000)
#define I2C_TRISTATE            (iop->pdir &= ~0x00010000)
#define I2C_READ                ((iop->pdat & 0x00010000) != 0)
#define I2C_SDA(bit)            if(bit) iop->pdat |=  0x00010000; \
                                else    iop->pdat &= ~0x00010000
#define I2C_SCL(bit)            if(bit) iop->pdat |=  0x00020000; \
                                else    iop->pdat &= ~0x00020000
#define I2C_DELAY               udelay(5)   /* 1/4 I2C clock duration */
#endif

/*
 * Initial stack pointer and data area (in DPRAM)
 *
 * CFG_INIT_SP_OFFSET : stack (CFG_INIT_RAM_END - CFG_GBL_DATA_SIZE)
 * CFG_GBL_DATA_OFFSET : initial data (CFG_GBL_DATA_SIZE)
 */

#define CFG_INIT_RAM_ADDR       CFG_IMMR
#define CFG_INIT_RAM_END        0x4000
#define CFG_GBL_DATA_SIZE       128
#define CFG_GBL_DATA_OFFSET     (CFG_INIT_RAM_END - CFG_GBL_DATA_SIZE)
#define CFG_INIT_SP_OFFSET      CFG_GBL_DATA_OFFSET

/*
 * Cache Configuration
 */

#define CFG_CACHELINE_SIZE      32      /* For MPC8260 CPU */


#if (CONFIG_COMMANDS & CFG_CMD_KGDB)
#  define CFG_CACHELINE_SHIFT   5       /* log base 2 of the above value */
#endif

/*
 * Flash memory
 */

#define CFG_MAX_FLASH_BANKS     1       /* max number of memory banks         */
#define CFG_MAX_FLASH_SECT      1024    /* max number of sectors on one chip  */

#define CFG_FLASH_ERASE_TOUT    8000    /* Timeout for Flash Erase (in ms)    */
#define CFG_FLASH_WRITE_TOUT    1       /* Timeout for Flash Write (in ms)    */

/* Environment variables and flash memory */
#define CFG_ENV_IS_IN_FLASH     1
#define CFG_ENV_IN_OWN_SECT
#define CONFIG_ENV_OVERWRITE

#define CFG_ENV_ADDR            (CFG_MONITOR_BASE + 0x40000)
#define CFG_ENV_SECT_SIZE       0x40000

/****************************************************************************
 *
 * Register definitions and system configurations
 *
 ****************************************************************************/

/*
 * Hard Reset Configuration Words
 *
 * Master : 0x08040287
 * No slaves
 */

#define CFG_SBC_HRCW_IMMR       (((CFG_IMMR & 0x10000000) >> 10) |\
                                ((CFG_IMMR & 0x01000000) >> 7)  |\
                                ((CFG_IMMR & 0x00100000) >> 4))

#define CFG_HRCW_MASTER         (HRCW_BPS10         |\
                                HRCW_L2CPC00        |\
                                HRCW_DPPC00         |\
                                CFG_SBC_HRCW_IMMR   |\
                                HRCW_APPC10         |\
                                HRCW_CS10PC10       |\
                                CFG_SBC_MODCK_H)

#define CFG_HRCW_SLAVE1         0
#define CFG_HRCW_SLAVE2         0
#define CFG_HRCW_SLAVE3         0
#define CFG_HRCW_SLAVE4         0
#define CFG_HRCW_SLAVE5         0
#define CFG_HRCW_SLAVE6         0
#define CFG_HRCW_SLAVE7         0

/*
 * Hardware Implementation-dependent Registers
 *
 * HID0 : Enable I and D caches, Invalidate I and D caches (init only)
 * HID2 : 0
 */

#define CFG_HID0_INIT           (HID0_ICE   |\
                                HID0_DCE    |\
                                HID0_ICFI   |\
                                HID0_DCI    |\
                                HID0_IFEM   |\
                                HID0_ABE)

#define CFG_HID0_FINAL          (HID0_ICE   |\
                                /* HID0_DCE    | */\
                                HID0_IFEM   |\
                                HID0_ABE    |\
                                HID0_EMCP)
#define CFG_HID2                0

/*
 * Reset Mode Register
 */

#define CFG_RMR                 0

/*
 * System Configuration and Protection Registers
 *
 * BCR : 0x10000000
 * SIUMCR : 0x00280000
 * SYPCR : 0xFFFFFF81
 */

#define CFG_BCR                 0x10000000
#define CFG_SIUMCR              (SIUMCR_APPC10  |\
                                SIUMCR_CS10PC10)
#define CFG_SYPCR               (SYPCR_SWTC     |\
                                SYPCR_BMT       |\
                                SYPCR_PBME      |\
                                SYPCR_SWP)

/*
 * Time Counter
 */

#define CFG_TMCNTSC             (TMCNTSC_SEC |\
                                TMCNTSC_ALR |\
                                TMCNTSC_TCF |\
                                TMCNTSC_TCE)

/*
 * Interrupt
 */

#define CFG_PISCR               (PISCR_PS  |\
                                PISCR_PTF |\
                                PISCR_PTE)

/* 
 * System Clock 
 */

#define CFG_SCCR                (SCCR_DFBRG01)

/* 
 * RISC Controller
 */

#define CFG_RCCR                0

/*
 * Init Memory Controller:
 *
 * Bank Bus     Machine PortSz  Device
 * ---- ---     ------- ------  ------
 *  0   60x     GPCM    16 bit  FLASH (BGA - 32MB AMD AM29LV256MH)
 *  1   Local   GPCM    32 bit  SWITCHCORE (CXE-1000 Register Interface)
 *  2   Local   GPCM    32 bit  SWITCHCORE (CXE-1000 Packet Interface)
 *  3   60x     SDRAM   64 bit  SDRAM (256MB MT46LC32M16A2 x 4)
 *  4   unused
 *  5   unused
 *  6   unused
 *  7   unused
 *  8   unused
 *  9   unused
 * 10   unused
 * 11   unused
*/

/*
 * BRx - Base Register
 * ORx - Option Register
 */

/* Bank 0 - FLASH
 * BR0 : 0x40001001
 * OR0 : 0xFE001054
 */

#define CFG_BR0_PRELIM          ((CFG_FLASH0_BASE & BRx_BA_MSK) |\
                                BRx_PS_16                       |\
                                BRx_DECC_NONE                   |\
                                BRx_MS_GPCM_P                   |\
                                BRx_V)

#define CFG_OR0_PRELIM          (MEG_TO_AM(CFG_FLASH0_SIZE)     |\
                                ORxG_BCTLD                      |\
                                ORxG_ACS_DIV1                   |\
                                ORxG_SCY_5_CLK                  |\
                                ORxG_TRLX)

/* Bank 1 - SWITCHCORE Register Interface
 * BR1 : 0x21001821
 * OR1 : 0xFFFF8EF4
 */

#define CFG_BR1_PRELIM          ((CFG_SWITCHCORE_REG_BASE & BRx_BA_MSK) |\
                                BRx_PS_32                       |\
                                BRx_DECC_NONE                   |\
                                BRx_MS_GPCM_L                   |\
                                BRx_V)

#define CFG_OR1_PRELIM          (P2SZ_TO_AM(CFG_SWITCHCORE_REG_SIZE)    |\
                                ORxG_CSNT                       |\
                                ORxG_ACS_DIV2                   |\
                                ORxG_SCY_15_CLK                 |\
                                ORxG_TRLX)

/* Bank 2 - SWITCHCORE Packet Interface
 * BR2 : 0x20001821
 * OR2 : 0xFFFF8EF4
 */

#define CFG_BR2_PRELIM          ((CFG_SWITCHCORE_PACKET_BASE & BRx_BA_MSK) |\
                                BRx_PS_32                       |\
                                BRx_DECC_NONE                   |\
                                BRx_MS_GPCM_L                   |\
                                BRx_V)

#define CFG_OR2_PRELIM          (P2SZ_TO_AM(CFG_SWITCHCORE_REG_SIZE)    |\
                                ORxG_CSNT                       |\
                                ORxG_ACS_DIV2                   |\
                                ORxG_SCY_15_CLK                 |\
                                ORxG_TRLX)

/* Bank 3 - SDRAM
 * BR3 : 0x00000041
 * OR3 : 0xF0002900
 */

#define CFG_BR3_PRELIM          ((CFG_SDRAM0_BASE & BRx_BA_MSK)         |\
                                BRx_PS_64                       |\
                                BRx_MS_SDRAM_P                  |\
                                BRx_V)

#define CFG_OR3_PRELIM          (MEG_TO_AM(CFG_SDRAM0_SIZE)     |\
                                ORxS_BPD_4                      |\
                                ORxS_ROWST_PBI1_A4              |\
                                ORxS_NUMR_13)

/* 
 * SDRAM configuration
 *
 * PSDMR : 0xC40124A2
 * PSRT : 0x0E
 * LSRT : No Local SDRAM
 * MPTPR : 0x2000
 */ 

#define CFG_PSDMR               (PSDMR_PBI              |\
                                PSDMR_RFEN              |\
                                PSDMR_OP_NORM           |\
                                PSDMR_SDAM_A17_IS_A5    |\
                                PSDMR_BSMA_A12_A14      |\
                                PSDMR_SDA10_PBI1_A10    |\
                                PSDMR_RFRC_4_CLK        |\
                                PSDMR_PRETOACT_2W       |\
                                PSDMR_ACTTORW_2W        |\
                                PSDMR_LDOTOPRE_2C       |\
                                PSDMR_WRC_2C            |\
                                PSDMR_CL_2)
                                
#define CFG_PSRT                0x0E
#define CFG_LSRT                0x0
#define CFG_MPTPR               (0x2000 & MPTPR_PTP_MSK)

#endif  /* __CONFIG_H */

